# LSM303D

STMicroelectronics accelerometer and magnetometer

- Device address 29
- Address type 7-bit

### Addr 136 8-bytes Read-only | # Magnetometer X ## Raw magnetometer data on X plane
### Addr 137 8-bytes Read-only | # Magnetometer X ## Raw magnetometer data on X plane
### Addr 138 8-bytes Read-only | # Magnetometer Y ## Raw magnetometer data on Y plane
### Addr 139 8-bytes Read-only | # Magnetometer Y ## Raw magnetometer data on Y plane
### Addr 140 8-bytes Read-only | # Magnetometer Z ## Raw magnetometer data on Z plane
### Addr 141 8-bytes Read-only | # Magnetometer Z ## Raw magnetometer data on Z plane
### Addr 168 8-bytes Read-only | # Accelerometer X ## Raw accelerometer data on X plane
### Addr 169 8-bytes Read-only | # Accelerometer X ## Raw accelerometer data on X plane
### Addr 170 8-bytes Read-only | # Accelerometer Y ## Raw accelerometer data on Y plane
### Addr 171 8-bytes Read-only | # Accelerometer Y ## Raw accelerometer data on Y plane
### Addr 172 8-bytes Read-only | # Accelerometer Z ## Raw accelerometer data on Z plane
### Addr 173 8-bytes Read-only | # Accelerometer Z ## Raw accelerometer data on Z plane

## Functions

- acceleration.asG - Measures the current acceleration
- acceleration.xPlane - Measures the current acceleration
- acceleration.yPlane - Measures the current acceleration
- acceleration.zPlane - Measures the current acceleration
- orientation.heading - Reads the magnetic orientation
- orientation.xPlane - Reads the magnetic orientation
- orientation.yPlane - Reads the magnetic orientation
- orientation.zPlane - Reads the magnetic orientation